# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class DiscussionServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribeDiscussionOutput"),
            **kwargs,
        )

    def ListDiscussions(self, request, **kwargs):
        path = "/discussions"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListDiscussionsOutput"),
            **kwargs,
        )

    def CreateDiscussion(self, request, **kwargs):
        path = "/discussions"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.CreateDiscussionOutput"),
            **kwargs,
        )

    def UpdateDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdateDiscussionOutput"),
            **kwargs,
        )

    def DeleteDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DeleteDiscussionOutput"),
            **kwargs,
        )

    def VoteDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)+"/vote"

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.VoteDiscussionOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/space.proto\x12\x0f\x65olymp.universe\x1a\x1b\x65olymp/universe/quota.proto\"\xbd\x03\n\x05Space\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\r\n\x05image\x18\x0b \x01(\t\x12)\n\x04type\x18\x0c \x01(\x0e\x32\x1b.eolymp.universe.Space.Type\x12\x35\n\nvisibility\x18\x0e \x01(\x0e\x32!.eolymp.universe.Space.Visibility\x12%\n\x05quota\x18\x1e \x01(\x0b\x32\x16.eolymp.universe.Quota\x12\x0c\n\x04plan\x18\r \x01(\t\x12\r\n\x05seats\x18\x1f \x01(\r\x12\x10\n\x08home_url\x18\x32 \x01(\t\x12\x12\n\nissuer_url\x18\x33 \x01(\t\x12\x13\n\x0bgraphql_url\x18\x34 \x01(\t\"Q\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\r\n\tCLASSROOM\x10\x02\x12\x0c\n\x08TEAMROOM\x10\x03\x12\x0f\n\x0b\x43OMPETITION\x10\x04\"=\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _SPACE._serialized_start=78
  _SPACE._serialized_end=523
  _SPACE_TYPE._serialized_start=379
  _SPACE_TYPE._serialized_end=460
  _SPACE_VISIBILITY._serialized_start=462
  _SPACE_VISIBILITY._serialized_end=523
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class KeeperClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateObject(self, request, **kwargs):
        path = "/objects"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.CreateObjectOutput"),
            **kwargs,
        )

    def DescribeObject(self, request, **kwargs):
        path = "/objects/"+urllib.parse.quote(request.key)

        # Cleanup URL parameters to avoid any ambiguity
        request.key = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.DescribeObjectOutput"),
            **kwargs,
        )

    def DownloadObject(self, request, **kwargs):
        path = "/objects/"+urllib.parse.quote(request.key)+"/data"

        # Cleanup URL parameters to avoid any ambiguity
        request.key = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.DownloadObjectOutput"),
            **kwargs,
        )

    def StartMultipartUpload(self, request, **kwargs):
        path = "/uploads"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.StartMultipartUploadOutput"),
            **kwargs,
        )

    def UploadPart(self, request, **kwargs):
        path = "/objects/"+urllib.parse.quote(request.object_id)+"/parts"

        # Cleanup URL parameters to avoid any ambiguity
        request.object_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.UploadPartOutput"),
            **kwargs,
        )

    def CompleteMultipartUpload(self, request, **kwargs):
        path = "/objects/"+urllib.parse.quote(request.object_id)+"/complete"

        # Cleanup URL parameters to avoid any ambiguity
        request.object_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.keeper.CompleteMultipartUploadOutput"),
            **kwargs,
        )

